==> kadu_0.6.0.orig.tar.gz: kadu/modules/history/translations/history_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1">
<context>
    <name>@default</name>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="53"/>
        <source>Chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="6"/>
        <source>History</source>
        <translation type="unfinished">Historique</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="9"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="12"/>
        <source>Save history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="14"/>
        <source>Save messages in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="18"/>
        <source>Status changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="21"/>
        <source>Don&apos;t show status changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="23"/>
        <source>Don&apos;t show status changes in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="26"/>
        <source>Don&apos;t save status changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="28"/>
        <source>Don&apos;t save status changes in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="32"/>
        <source>Citation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="35"/>
        <source>Message citation in chat window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="38"/>
        <source>Don&apos;t cite messages older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="41"/>
        <source>.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="47"/>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="56"/>
        <source>View history</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <location filename="../history_dialog.cpp" line="77"/>
        <source>History</source>
        <translation>Historique</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="98"/>
        <source>&amp;Find</source>
        <translation>&amp;Trouves</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="99"/>
        <source>Find &amp;next</source>
        <translation>Trouves &amp;suivant</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="100"/>
        <source>Find &amp;previous</source>
        <translation>Trouves &amp;celui d&apos;avant</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="216"/>
        <source>Online</source>
        <translation>Accessible</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="220"/>
        <source>Busy</source>
        <translation>Je reviens bientôt</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="224"/>
        <source>Invisible</source>
        <translation>Caché</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="228"/>
        <source>Offline</source>
        <translation>Non disponible</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="84"/>
        <source>Uins</source>
        <translation>Numéro GG</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="91"/>
        <source>Show status changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="231"/>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryManager</name>
    <message>
        <location filename="../history.cpp" line="324"/>
        <source>Clear history?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../history.cpp" line="325"/>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../history.cpp" line="325"/>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryModule</name>
    <message>
        <location filename="../history_module.cpp" line="75"/>
        <source>Show history</source>
        <translation>Montre historique</translation>
    </message>
    <message>
        <location filename="../history_module.cpp" line="335"/>
        <source>History</source>
        <translation type="unfinished">Historique</translation>
    </message>
    <message>
        <location filename="../history_module.cpp" line="336"/>
        <source>Clear history</source>
        <translation type="unfinished">Efface historique</translation>
    </message>
    <message>
        <location filename="../history_module.cpp" line="140"/>
        <source>%1 day(s) %2 hour(s)</source>
        <translation type="unfinished">jours: %1 heures: %2</translation>
    </message>
    <message>
        <location filename="../history_module.cpp" line="354"/>
        <source>The following users were deleted:
%0
Do you want to remove history as well?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistorySearchDialog</name>
    <message>
        <location filename="../history_search_dialog.cpp" line="39"/>
        <source>Search history</source>
        <translation>Cherche dans l&apos;historique</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="67"/>
        <source>&amp;From:</source>
        <translation>&amp;de:</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="90"/>
        <source>day</source>
        <translation>jour</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="93"/>
        <source>month</source>
        <translation>mois</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="96"/>
        <source>year</source>
        <translation>année</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="99"/>
        <source>hour</source>
        <translation>heure</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="102"/>
        <source>minute</source>
        <translation>min.</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="86"/>
        <source>&amp;To:</source>
        <translation>&amp;à:</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="104"/>
        <source>Find Criteria</source>
        <translation>Critères de recherche</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="105"/>
        <source>&amp;Pattern</source>
        <translation>&amp;Exemple</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="106"/>
        <source>&amp;Status</source>
        <translation>&amp;Statut</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="112"/>
        <source>Pattern</source>
        <translation>Exemple</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="114"/>
        <source>Status</source>
        <translation>Statut</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="119"/>
        <source>&amp;Reverse find</source>
        <translation>&amp;Recherche en arrière</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="121"/>
        <source>&amp;Find</source>
        <translation>&amp;Trouves</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="122"/>
        <source>Reset</source>
        <translation>Effaces</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="123"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annule</translation>
    </message>
</context>
</TS>

==> kadu_0.6.0.2.orig.tar.gz: kadu/modules/history/translations/history_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1">
<context>
    <name>@default</name>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="53"/>
        <source>Chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="6"/>
        <source>History</source>
        <translation type="unfinished">Historique</translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="9"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="12"/>
        <source>Save history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="14"/>
        <source>Save messages in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="18"/>
        <source>Status changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="21"/>
        <source>Don&apos;t show status changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="23"/>
        <source>Don&apos;t show status changes in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="26"/>
        <source>Don&apos;t save status changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="28"/>
        <source>Don&apos;t save status changes in history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="32"/>
        <source>Citation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="35"/>
        <source>Message citation in chat window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="38"/>
        <source>Don&apos;t cite messages older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="41"/>
        <source>.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="47"/>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../.configuration-ui-translations.cpp" line="56"/>
        <source>View history</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <location filename="../history_dialog.cpp" line="77"/>
        <source>History</source>
        <translation>Historique</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="98"/>
        <source>&amp;Find</source>
        <translation>&amp;Trouves</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="99"/>
        <source>Find &amp;next</source>
        <translation>Trouves &amp;suivant</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="100"/>
        <source>Find &amp;previous</source>
        <translation>Trouves &amp;celui d&apos;avant</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="216"/>
        <source>Online</source>
        <translation>Accessible</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="220"/>
        <source>Busy</source>
        <translation>Je reviens bientôt</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="224"/>
        <source>Invisible</source>
        <translation>Caché</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="228"/>
        <source>Offline</source>
        <translation>Non disponible</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="84"/>
        <source>Uins</source>
        <translation>Numéro GG</translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="91"/>
        <source>Show status changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../history_dialog.cpp" line="231"/>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryManager</name>
    <message>
        <location filename="../history.cpp" line="324"/>
        <source>Clear history?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../history.cpp" line="325"/>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../history.cpp" line="325"/>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryModule</name>
    <message>
        <location filename="../history_module.cpp" line="75"/>
        <source>Show history</source>
        <translation>Montre historique</translation>
    </message>
    <message>
        <location filename="../history_module.cpp" line="335"/>
        <source>History</source>
        <translation type="unfinished">Historique</translation>
    </message>
    <message>
        <location filename="../history_module.cpp" line="336"/>
        <source>Clear history</source>
        <translation type="unfinished">Efface historique</translation>
    </message>
    <message>
        <location filename="../history_module.cpp" line="140"/>
        <source>%1 day(s) %2 hour(s)</source>
        <translation type="unfinished">jours: %1 heures: %2</translation>
    </message>
    <message>
        <location filename="../history_module.cpp" line="354"/>
        <source>The following users were deleted:
%0Do you want to remove history as well?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistorySearchDialog</name>
    <message>
        <location filename="../history_search_dialog.cpp" line="39"/>
        <source>Search history</source>
        <translation>Cherche dans l&apos;historique</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="67"/>
        <source>&amp;From:</source>
        <translation>&amp;de:</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="90"/>
        <source>day</source>
        <translation>jour</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="93"/>
        <source>month</source>
        <translation>mois</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="96"/>
        <source>year</source>
        <translation>année</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="99"/>
        <source>hour</source>
        <translation>heure</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="102"/>
        <source>minute</source>
        <translation>min.</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="86"/>
        <source>&amp;To:</source>
        <translation>&amp;à:</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="104"/>
        <source>Find Criteria</source>
        <translation>Critères de recherche</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="105"/>
        <source>&amp;Pattern</source>
        <translation>&amp;Exemple</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="106"/>
        <source>&amp;Status</source>
        <translation>&amp;Statut</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="112"/>
        <source>Pattern</source>
        <translation>Exemple</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="114"/>
        <source>Status</source>
        <translation>Statut</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="119"/>
        <source>&amp;Reverse find</source>
        <translation>&amp;Recherche en arrière</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="121"/>
        <source>&amp;Find</source>
        <translation>&amp;Trouves</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="122"/>
        <source>Reset</source>
        <translation>Effaces</translation>
    </message>
    <message>
        <location filename="../history_search_dialog.cpp" line="123"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annule</translation>
    </message>
</context>
</TS>
